@@ -572,17 +572,21 @@ fr_command_7z_handle_error (FrCommand *command,
 }
 
 
-const char *sevenz_mime_types[] = { "application/x-7z-compressed",
-				    "application/x-arj",
-				    "application/vnd.ms-cab-compressed",
-				    "application/x-cd-image",
-				    /*"application/x-cbr",*/
-				    "application/x-cbz",
-				    "application/x-ms-dos-executable",
-				    "application/x-ms-wim",
-				    "application/x-rar",
-				    "application/zip",
-				    NULL };
+const char *sevenz_mime_types[] = {
+	"application/epub+zip",
+	"application/x-7z-compressed",
+	"application/x-arj",
+	"application/vnd.ms-cab-compressed",
+	"application/x-cd-image",
+	"application/x-chrome-extension",
+	/*"application/x-cbr",*/
+	"application/x-cbz",
+	"application/x-ms-dos-executable",
+	"application/x-ms-wim",
+	"application/x-rar",
+	"application/zip",
+	NULL
+};
 
 
 static const char **
